@@ -3,13 +3,13 @@ Test fixtures common to more than one test point.
 """
 import os
 import re
+import subprocess
 import sys
 import textwrap
 import unittest
 import warnings
 
 import numpy as np
-import six
 
 import glymur
 
@@ -21,23 +21,38 @@ else:
     OPENJPEG_NOT_AVAILABLE = False
     OPENJPEG_NOT_AVAILABLE_MSG = None
 
-# Some versions of "six" on python3 cause problems when verifying warnings.
-# Only use when the version is 1.7 or higher.
-# And moreover, we only test using the 3.x infrastructure, never on 2.x.
-WARNING_INFRASTRUCTURE_ISSUE = False
-WARNING_INFRASTRUCTURE_MSG = ""
-if sys.hexversion < 0x03000000:
-    WARNING_INFRASTRUCTURE_ISSUE = True
-    WARNING_INFRASTRUCTURE_MSG = "3.x warning infrastructure only"
-elif re.match('1.[0-6]', six.__version__) is not None:
-    WARNING_INFRASTRUCTURE_ISSUE = True
-    msg = "Cannot run test with version {0} of python-six"
-    WARNING_INFRASTRUCTURE_MSG = msg.format(six.__version__)
-
 # Cannot reopen a named temporary file in windows.
 WINDOWS_TMP_FILE_MSG = "cannot use NamedTemporaryFile like this in windows"
 
 
+def low_memory_linux_machine():
+    """
+    Detect if the current machine is low-memory (< 2.5GB)
+
+    This is primarily aimed at Digital Ocean VMs running linux.  Don't bother
+    on mac or windows.
+
+    Returns
+    -------
+    bool
+        True if <2GB, False otherwise
+    """
+    if not sys.platform.startswith('linux'):
+        return False
+    cmd1 = "free -m"
+    cmd2 = "tail -n +2"
+    cmd3 = "awk '{sum += $2} END {print sum}'"
+    p1 = subprocess.Popen(cmd1, shell=True, stdout=subprocess.PIPE)
+    p2 = subprocess.Popen(cmd2, shell=True,
+                          stdin=p1.stdout, stdout=subprocess.PIPE)
+    p3 = subprocess.Popen(cmd3, shell=True,
+                          stdin=p2.stdout, stdout=subprocess.PIPE)
+    p1.stdout.close()
+    p2.stdout.close()
+    stdout, stderr = p3.communicate()
+    nbytes = int(stdout.decode('utf-8').strip())
+    return nbytes < 2000
+
 class MetadataBase(unittest.TestCase):
     """
     Base class for testing metadata.
@@ -174,14 +189,6 @@ except:
 NO_READ_BACKEND_MSG = "Matplotlib with the PIL backend must be available in "
 NO_READ_BACKEND_MSG += "order to run the tests in this suite."
 
-try:
-    OPJ_DATA_ROOT = os.environ['OPJ_DATA_ROOT']
-except KeyError:
-    OPJ_DATA_ROOT = None
-except:
-    raise
-
-
 # The Cinema2K/4K tests seem to need the freeimage backend to skimage.io
 # in order to work.  Unfortunately, scikit-image/freeimage is about as wonky as
 # it gets.  Anaconda can get totally weirded out on versions up through 3.6.4
@@ -232,11 +239,6 @@ def _indent(textstr):
         return '\n'.join(lst)
 
 
-def opj_data_file(relative_file_name):
-    """Compact way of forming a full filename from OpenJPEG's test suite."""
-    jfile = os.path.join(OPJ_DATA_ROOT, relative_file_name)
-    return jfile
-
 try:
     import matplotlib
     if not re.match('[1-9]\.[3-9]', matplotlib.__version__):
@@ -274,106 +276,6 @@ def mse(amat, bmat):
     return err
 
 
-def peak_tolerance(amat, bmat):
-    """Peak Tolerance"""
-    diff = np.abs(amat.astype(np.double) - bmat.astype(np.double))
-    ptol = diff.max()
-    return ptol
-
-
-def read_pgx(pgx_file):
-    """Helper function for reading the PGX comparison files.
-    """
-    header, pos = read_pgx_header(pgx_file)
-
-    tokens = re.split(r'\s', header)
-
-    if (tokens[1][0] == 'M') and (sys.byteorder == 'little'):
-        swapbytes = True
-    elif (tokens[1][0] == 'L') and (sys.byteorder == 'big'):
-        swapbytes = True
-    else:
-        swapbytes = False
-
-    if (len(tokens) == 6):
-        bitdepth = int(tokens[3])
-        signed = bitdepth < 0
-        if signed:
-            bitdepth = -1 * bitdepth
-        nrows = int(tokens[5])
-        ncols = int(tokens[4])
-    else:
-        bitdepth = int(tokens[2])
-        signed = bitdepth < 0
-        if signed:
-            bitdepth = -1 * bitdepth
-        nrows = int(tokens[4])
-        ncols = int(tokens[3])
-
-    dtype = determine_pgx_datatype(signed, bitdepth)
-
-    shape = [nrows, ncols]
-
-    # Reopen the file in binary mode and seek to the start of the binary
-    # data
-    with open(pgx_file, 'rb') as fptr:
-        fptr.seek(pos)
-        data = np.fromfile(file=fptr, dtype=dtype).reshape(shape)
-
-    return(data.byteswap(swapbytes))
-
-
-def determine_pgx_datatype(signed, bitdepth):
-    """Determine the datatype of the PGX file.
-
-    Parameters
-    ----------
-    signed : bool
-        True if the datatype is signed, false otherwise
-    bitdepth : int
-        How many bits are used to make up an image plane.  Should be 8 or 16.
-    """
-    if signed:
-        if bitdepth <= 8:
-            dtype = np.int8
-        elif bitdepth <= 16:
-            dtype = np.int16
-        else:
-            raise RuntimeError("unhandled bitdepth")
-    else:
-        if bitdepth <= 8:
-            dtype = np.uint8
-        elif bitdepth <= 16:
-            dtype = np.uint16
-        else:
-            raise RuntimeError("unhandled bitdepth")
-
-    return dtype
-
-
-def read_pgx_header(pgx_file):
-    """Open the file in ascii mode (not really) and read the header line.
-    Will look something like
-
-    PG ML + 8 128 128
-    PG%[ \t]%c%c%[ \t+-]%d%[ \t]%d%[ \t]%d"
-    """
-    header = ''
-    with open(pgx_file, 'rb') as fptr:
-        while True:
-            char = fptr.read(1)
-            if char[0] == 10 or char == '\n':
-                pos = fptr.tell()
-                break
-            else:
-                if sys.hexversion < 0x03000000:
-                    header += char
-                else:
-                    header += chr(char[0])
-
-    header = header.rstrip()
-    return header, pos
-
 nemo_xmp = """<?xpacket begin="" id="W5M0MpCehiHzreSzNTczkc9d"?>
 <ns0:xmpmeta xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:ns0="adobe:ns:meta/" xmlns:ns2="http://ns.adobe.com/xap/1.0/" xmlns:ns3="http://ns.adobe.com/tiff/1.0/" xmlns:ns4="http://ns.adobe.com/exif/1.0/" xmlns:ns5="http://ns.adobe.com/photoshop/1.0/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" ns0:xmptk="Exempi + XMP Core 5.1.2">
  <rdf:RDF>
@@ -459,10 +361,6 @@ nemo_xmp = """<?xpacket begin="" id="W5M0MpCehiHzreSzNTczkc9d"?>
  </rdf:RDF>
 </ns0:xmpmeta>
 <?xpacket end="w"?>"""
-nemo_xmp_box = """UUID Box (uuid) @ (77, 3146)
-    UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
-    UUID Data:
-{0}""".format(_indent(nemo_xmp))
 
 nemo_xmp_box = """UUID Box (uuid) @ (77, 3146)
     UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
@@ -577,10 +475,10 @@ text_gbr_35 = """Colour Specification Box (colr) @ (179, 1339)
 
 
 # Metadata dump of nemo.
-dump = r'''JPEG 2000 Signature Box (jP  ) @ (0, 12)
+nemo_fmt = r'''JPEG 2000 Signature Box (jP  ) @ (0, 12)
     Signature:  0d0a870a
 File Type Box (ftyp) @ (12, 20)
-    Brand:  jp2
+    Brand:  jp2 
     Compatibility:  ['jp2 ']
 JP2 Header Box (jp2h) @ (32, 45)
     Image Header Box (ihdr) @ (40, 22)
@@ -596,46 +494,99 @@ JP2 Header Box (jp2h) @ (32, 45)
 UUID Box (uuid) @ (77, 3146)
     UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
     UUID Data:
-{0}
+{xmp}
 Contiguous Codestream Box (jp2c) @ (3223, 1132296)
-    Main header:
-        SOC marker segment @ (3231, 0)
-        SIZ marker segment @ (3233, 47)
-            Profile:  no profile
-            Reference Grid Height, Width:  (1456 x 2592)
-            Vertical, Horizontal Reference Grid Offset:  (0 x 0)
-            Reference Tile Height, Width:  (1456 x 2592)
-            Vertical, Horizontal Reference Tile Offset:  (0 x 0)
-            Bitdepth:  (8, 8, 8)
-            Signed:  (False, False, False)
-            Vertical, Horizontal Subsampling:  ((1, 1), (1, 1), (1, 1))
-        COD marker segment @ (3282, 12)
-            Coding style:
-                Entropy coder, without partitions
-                SOP marker segments:  False
-                EPH marker segments:  False
-            Coding style parameters:
-                Progression order:  LRCP
-                Number of layers:  2
-                Multiple component transformation usage:  reversible
-                Number of resolutions:  2
-                Code block height, width:  (64 x 64)
-                Wavelet transform:  5-3 reversible
-                Precinct size:  default, 2^15 x 2^15
-                Code block context:
-                    Selective arithmetic coding bypass:  False
-                    Reset context probabilities on coding pass boundaries:  False
-                    Termination on each coding pass:  False
-                    Vertically stripe causal context:  False
-                    Predictable termination:  False
-                    Segmentation symbols:  False
-        QCD marker segment @ (3296, 7)
-            Quantization style:  no quantization, 2 guard bits
-            Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
-        CME marker segment @ (3305, 37)
-            "Created by OpenJPEG version 2.0.0"'''
+{codestream}'''
 
-nemo_with_codestream_header = dump.format(_indent(nemo_xmp))
+codestream_header = '''SOC marker segment @ (3231, 0)
+SIZ marker segment @ (3233, 47)
+    Profile:  no profile
+    Reference Grid Height, Width:  (1456 x 2592)
+    Vertical, Horizontal Reference Grid Offset:  (0 x 0)
+    Reference Tile Height, Width:  (1456 x 2592)
+    Vertical, Horizontal Reference Tile Offset:  (0 x 0)
+    Bitdepth:  (8, 8, 8)
+    Signed:  (False, False, False)
+    Vertical, Horizontal Subsampling:  ((1, 1), (1, 1), (1, 1))
+COD marker segment @ (3282, 12)
+    Coding style:
+        Entropy coder, without partitions
+        SOP marker segments:  False
+        EPH marker segments:  False
+    Coding style parameters:
+        Progression order:  LRCP
+        Number of layers:  2
+        Multiple component transformation usage:  reversible
+        Number of resolutions:  2
+        Code block height, width:  (64 x 64)
+        Wavelet transform:  5-3 reversible
+        Precinct size:  (32768, 32768)
+        Code block context:
+            Selective arithmetic coding bypass:  False
+            Reset context probabilities on coding pass boundaries:  False
+            Termination on each coding pass:  False
+            Vertically stripe causal context:  False
+            Predictable termination:  False
+            Segmentation symbols:  False
+QCD marker segment @ (3296, 7)
+    Quantization style:  no quantization, 2 guard bits
+    Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
+CME marker segment @ (3305, 37)
+    "Created by OpenJPEG version 2.0.0"'''
+
+codestream_trailer = """SOT marker segment @ (3344, 10)
+    Tile part index:  0
+    Tile part length:  1132173
+    Tile part instance:  0
+    Number of tile parts:  1
+COC marker segment @ (3356, 9)
+    Associated component:  1
+    Coding style for this component:  Entropy coder, PARTITION = 0
+    Coding style parameters:
+        Number of resolutions:  2
+        Code block height, width:  (64 x 64)
+        Wavelet transform:  5-3 reversible
+        Precinct size:  (32768, 32768)
+        Code block context:
+            Selective arithmetic coding bypass:  False
+            Reset context probabilities on coding pass boundaries:  False
+            Termination on each coding pass:  False
+            Vertically stripe causal context:  False
+            Predictable termination:  False
+            Segmentation symbols:  False
+QCC marker segment @ (3367, 8)
+    Associated Component:  1
+    Quantization style:  no quantization, 2 guard bits
+    Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
+COC marker segment @ (3377, 9)
+    Associated component:  2
+    Coding style for this component:  Entropy coder, PARTITION = 0
+    Coding style parameters:
+        Number of resolutions:  2
+        Code block height, width:  (64 x 64)
+        Wavelet transform:  5-3 reversible
+        Precinct size:  (32768, 32768)
+        Code block context:
+            Selective arithmetic coding bypass:  False
+            Reset context probabilities on coding pass boundaries:  False
+            Termination on each coding pass:  False
+            Vertically stripe causal context:  False
+            Predictable termination:  False
+            Segmentation symbols:  False
+QCC marker segment @ (3388, 8)
+    Associated Component:  2
+    Quantization style:  no quantization, 2 guard bits
+    Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
+SOD marker segment @ (3398, 0)
+EOC marker segment @ (1135517, 0)"""
+
+codestream = '\n'.join([codestream_header, codestream_trailer])
+
+_kwargs = {
+    'xmp': _indent(nemo_xmp),
+    'codestream': _indent(codestream_header)
+}
+nemo_with_codestream_header = nemo_fmt.format(**_kwargs)
 
 nemo_dump_short = r"""JPEG 2000 Signature Box (jP  ) @ (0, 12)
 File Type Box (ftyp) @ (12, 20)
@@ -645,66 +596,10 @@ JP2 Header Box (jp2h) @ (32, 45)
 UUID Box (uuid) @ (77, 3146)
 Contiguous Codestream Box (jp2c) @ (3223, 1132296)"""
 
-nemo_dump_no_xml = '''JPEG 2000 Signature Box (jP  ) @ (0, 12)
+_fmt = """JPEG 2000 Signature Box (jP  ) @ (0, 12)
     Signature:  0d0a870a
 File Type Box (ftyp) @ (12, 20)
-    Brand:  jp2
-    Compatibility:  ['jp2 ']
-JP2 Header Box (jp2h) @ (32, 45)
-    Image Header Box (ihdr) @ (40, 22)
-        Size:  [1456 2592 3]
-        Bitdepth:  8
-        Signed:  False
-        Compression:  wavelet
-        Colorspace Unknown:  False
-    Colour Specification Box (colr) @ (62, 15)
-        Method:  enumerated colorspace
-        Precedence:  0
-        Colorspace:  sRGB
-UUID Box (uuid) @ (77, 3146)
-    UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
-Contiguous Codestream Box (jp2c) @ (3223, 1132296)
-    Main header:
-        SOC marker segment @ (3231, 0)
-        SIZ marker segment @ (3233, 47)
-            Profile:  no profile
-            Reference Grid Height, Width:  (1456 x 2592)
-            Vertical, Horizontal Reference Grid Offset:  (0 x 0)
-            Reference Tile Height, Width:  (1456 x 2592)
-            Vertical, Horizontal Reference Tile Offset:  (0 x 0)
-            Bitdepth:  (8, 8, 8)
-            Signed:  (False, False, False)
-            Vertical, Horizontal Subsampling:  ((1, 1), (1, 1), (1, 1))
-        COD marker segment @ (3282, 12)
-            Coding style:
-                Entropy coder, without partitions
-                SOP marker segments:  False
-                EPH marker segments:  False
-            Coding style parameters:
-                Progression order:  LRCP
-                Number of layers:  2
-                Multiple component transformation usage:  reversible
-                Number of resolutions:  2
-                Code block height, width:  (64 x 64)
-                Wavelet transform:  5-3 reversible
-                Precinct size:  default, 2^15 x 2^15
-                Code block context:
-                    Selective arithmetic coding bypass:  False
-                    Reset context probabilities on coding pass boundaries:  False
-                    Termination on each coding pass:  False
-                    Vertically stripe causal context:  False
-                    Predictable termination:  False
-                    Segmentation symbols:  False
-        QCD marker segment @ (3296, 7)
-            Quantization style:  no quantization, 2 guard bits
-            Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
-        CME marker segment @ (3305, 37)
-            "Created by OpenJPEG version 2.0.0"'''
-
-dump = r"""JPEG 2000 Signature Box (jP  ) @ (0, 12)
-    Signature:  0d0a870a
-File Type Box (ftyp) @ (12, 20)
-    Brand:  jp2
+    Brand:  jp2 
     Compatibility:  ['jp2 ']
 JP2 Header Box (jp2h) @ (32, 45)
     Image Header Box (ihdr) @ (40, 22)
@@ -720,9 +615,10 @@ JP2 Header Box (jp2h) @ (32, 45)
 UUID Box (uuid) @ (77, 3146)
     UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
     UUID Data:
-{0}
+{xmp}
 Contiguous Codestream Box (jp2c) @ (3223, 1132296)"""
-nemo_dump_no_codestream = dump.format(_indent(nemo_xmp))
+nemo_dump_no_codestream = _fmt.format(xmp=_indent(nemo_xmp))
+
 
 nemo_dump_no_codestream_no_xml = r"""JPEG 2000 Signature Box (jP  ) @ (0, 12)
     Signature:  0d0a870a
@@ -744,7 +640,13 @@ UUID Box (uuid) @ (77, 3146)
     UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
 Contiguous Codestream Box (jp2c) @ (3223, 1132296)"""
 
-nemo = """JPEG 2000 Signature Box (jP  ) @ (0, 12)
+_kwargs = {
+    'xmp': _indent(nemo_xmp),
+    'codestream': _indent(codestream)
+}
+nemo = nemo_fmt.format(**_kwargs)
+
+_fmt = '''JPEG 2000 Signature Box (jP  ) @ (0, 12)
     Signature:  0d0a870a
 File Type Box (ftyp) @ (12, 20)
     Brand:  jp2 
@@ -762,171 +664,9 @@ JP2 Header Box (jp2h) @ (32, 45)
         Colorspace:  sRGB
 UUID Box (uuid) @ (77, 3146)
     UUID:  be7acfcb-97a9-42e8-9c71-999491e3afac (XMP)
-    UUID Data:
-    <?xpacket begin="" id="W5M0MpCehiHzreSzNTczkc9d"?>
-    <ns0:xmpmeta xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:ns0="adobe:ns:meta/" xmlns:ns2="http://ns.adobe.com/xap/1.0/" xmlns:ns3="http://ns.adobe.com/tiff/1.0/" xmlns:ns4="http://ns.adobe.com/exif/1.0/" xmlns:ns5="http://ns.adobe.com/photoshop/1.0/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" ns0:xmptk="Exempi + XMP Core 5.1.2">
-     <rdf:RDF>
-      <rdf:Description rdf:about="">
-       <ns2:CreatorTool>Google</ns2:CreatorTool>
-       <ns2:CreateDate>2013-02-09T14:47:53</ns2:CreateDate>
-      </rdf:Description>
-      <rdf:Description rdf:about="">
-       <ns3:YCbCrPositioning>1</ns3:YCbCrPositioning>
-       <ns3:XResolution>72/1</ns3:XResolution>
-       <ns3:YResolution>72/1</ns3:YResolution>
-       <ns3:ResolutionUnit>2</ns3:ResolutionUnit>
-       <ns3:Make>HTC</ns3:Make>
-       <ns3:Model>HTC Glacier</ns3:Model>
-       <ns3:ImageWidth>2592</ns3:ImageWidth>
-       <ns3:ImageLength>1456</ns3:ImageLength>
-       <ns3:BitsPerSample>
-        <rdf:Seq>
-         <rdf:li>8</rdf:li>
-         <rdf:li>8</rdf:li>
-         <rdf:li>8</rdf:li>
-        </rdf:Seq>
-       </ns3:BitsPerSample>
-       <ns3:PhotometricInterpretation>2</ns3:PhotometricInterpretation>
-       <ns3:SamplesPerPixel>3</ns3:SamplesPerPixel>
-       <ns3:WhitePoint>
-        <rdf:Seq>
-         <rdf:li>1343036288/4294967295</rdf:li>
-         <rdf:li>1413044224/4294967295</rdf:li>
-        </rdf:Seq>
-       </ns3:WhitePoint>
-       <ns3:PrimaryChromaticities>
-        <rdf:Seq>
-         <rdf:li>2748779008/4294967295</rdf:li>
-         <rdf:li>1417339264/4294967295</rdf:li>
-         <rdf:li>1288490240/4294967295</rdf:li>
-         <rdf:li>2576980480/4294967295</rdf:li>
-         <rdf:li>644245120/4294967295</rdf:li>
-         <rdf:li>257698032/4294967295</rdf:li>
-        </rdf:Seq>
-       </ns3:PrimaryChromaticities>
-      </rdf:Description>
-      <rdf:Description rdf:about="">
-       <ns4:ColorSpace>1</ns4:ColorSpace>
-       <ns4:PixelXDimension>2528</ns4:PixelXDimension>
-       <ns4:PixelYDimension>1424</ns4:PixelYDimension>
-       <ns4:FocalLength>353/100</ns4:FocalLength>
-       <ns4:GPSAltitudeRef>0</ns4:GPSAltitudeRef>
-       <ns4:GPSAltitude>0/1</ns4:GPSAltitude>
-       <ns4:GPSMapDatum>WGS-84</ns4:GPSMapDatum>
-       <ns4:DateTimeOriginal>2013-02-09T14:47:53</ns4:DateTimeOriginal>
-       <ns4:ISOSpeedRatings>
-        <rdf:Seq>
-         <rdf:li>76</rdf:li>
-        </rdf:Seq>
-       </ns4:ISOSpeedRatings>
-       <ns4:ExifVersion>0220</ns4:ExifVersion>
-       <ns4:FlashpixVersion>0100</ns4:FlashpixVersion>
-       <ns4:ComponentsConfiguration>
-        <rdf:Seq>
-         <rdf:li>1</rdf:li>
-         <rdf:li>2</rdf:li>
-         <rdf:li>3</rdf:li>
-         <rdf:li>0</rdf:li>
-        </rdf:Seq>
-       </ns4:ComponentsConfiguration>
-       <ns4:GPSLatitude>42,20.56N</ns4:GPSLatitude>
-       <ns4:GPSLongitude>71,5.29W</ns4:GPSLongitude>
-       <ns4:GPSTimeStamp>2013-02-09T19:47:53Z</ns4:GPSTimeStamp>
-       <ns4:GPSProcessingMethod>NETWORK</ns4:GPSProcessingMethod>
-      </rdf:Description>
-      <rdf:Description rdf:about="">
-       <ns5:DateCreated>2013-02-09T14:47:53</ns5:DateCreated>
-      </rdf:Description>
-      <rdf:Description rdf:about="">
-       <dc:Creator>
-        <rdf:Seq>
-         <rdf:li>Glymur</rdf:li>
-         <rdf:li>Python XMP Toolkit</rdf:li>
-        </rdf:Seq>
-       </dc:Creator>
-      </rdf:Description>
-     </rdf:RDF>
-    </ns0:xmpmeta>
-    <?xpacket end="w"?>
 Contiguous Codestream Box (jp2c) @ (3223, 1132296)
-    SOC marker segment @ (3231, 0)
-    SIZ marker segment @ (3233, 47)
-        Profile:  no profile
-        Reference Grid Height, Width:  (1456 x 2592)
-        Vertical, Horizontal Reference Grid Offset:  (0 x 0)
-        Reference Tile Height, Width:  (1456 x 2592)
-        Vertical, Horizontal Reference Tile Offset:  (0 x 0)
-        Bitdepth:  (8, 8, 8)
-        Signed:  (False, False, False)
-        Vertical, Horizontal Subsampling:  ((1, 1), (1, 1), (1, 1))
-    COD marker segment @ (3282, 12)
-        Coding style:
-            Entropy coder, without partitions
-            SOP marker segments:  False
-            EPH marker segments:  False
-        Coding style parameters:
-            Progression order:  LRCP
-            Number of layers:  2
-            Multiple component transformation usage:  reversible
-            Number of resolutions:  2
-            Code block height, width:  (64 x 64)
-            Wavelet transform:  5-3 reversible
-            Precinct size:  default, 2^15 x 2^15
-            Code block context:
-                Selective arithmetic coding bypass:  False
-                Reset context probabilities on coding pass boundaries:  False
-                Termination on each coding pass:  False
-                Vertically stripe causal context:  False
-                Predictable termination:  False
-                Segmentation symbols:  False
-    QCD marker segment @ (3296, 7)
-        Quantization style:  no quantization, 2 guard bits
-        Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
-    CME marker segment @ (3305, 37)
-        "Created by OpenJPEG version 2.0.0"
-    SOT marker segment @ (3344, 10)
-        Tile part index:  0
-        Tile part length:  1132173
-        Tile part instance:  0
-        Number of tile parts:  1
-    COC marker segment @ (3356, 9)
-        Associated component:  1
-        Coding style for this component:  Entropy coder, PARTITION = 0
-        Coding style parameters:
-            Number of resolutions:  2
-            Code block height, width:  (64 x 64)
-            Wavelet transform:  5-3 reversible
-            Code block context:
-                Selective arithmetic coding bypass:  False
-                Reset context probabilities on coding pass boundaries:  False
-                Termination on each coding pass:  False
-                Vertically stripe causal context:  False
-                Predictable termination:  False
-                Segmentation symbols:  False
-    QCC marker segment @ (3367, 8)
-        Associated Component:  1
-        Quantization style:  no quantization, 2 guard bits
-        Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
-    COC marker segment @ (3377, 9)
-        Associated component:  2
-        Coding style for this component:  Entropy coder, PARTITION = 0
-        Coding style parameters:
-            Number of resolutions:  2
-            Code block height, width:  (64 x 64)
-            Wavelet transform:  5-3 reversible
-            Code block context:
-                Selective arithmetic coding bypass:  False
-                Reset context probabilities on coding pass boundaries:  False
-                Termination on each coding pass:  False
-                Vertically stripe causal context:  False
-                Predictable termination:  False
-                Segmentation symbols:  False
-    QCC marker segment @ (3388, 8)
-        Associated Component:  2
-        Quantization style:  no quantization, 2 guard bits
-        Step size:  [(0, 8), (0, 9), (0, 9), (0, 10)]
-    SOD marker segment @ (3398, 0)
-    EOC marker segment @ (1135517, 0)"""
+{codestream}'''
+nemo_dump_no_xml = _fmt.format(codestream=_indent(codestream_header))
 
 # Output of reader requirements printing for text_GBR.jp2
 text_GBR_rreq = r"""Reader Requirements Box (rreq) @ (40, 109)
@@ -944,12 +684,19 @@ text_GBR_rreq = r"""Reader Requirements Box (rreq) @ (40, 109)
         UUID bc45a774-dd50-4ec6-a9f6-f3a137f47e90
         UUID d7c8c5ef-951f-43b2-8757-042500f538e8"""
 
-file1_xml = """XML Box (xml ) @ (36, 439)
+file1_xml = """<IMAGE_CREATION xmlns="http://www.jpeg.org/jpx/1.0/xml" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.jpeg.org/jpx/1.0/xml http://www.jpeg.org/metadata/15444-2.xsd">
+    <GENERAL_CREATION_INFO>
+        <CREATION_TIME>2001-11-01T13:45:00.000-06:00</CREATION_TIME>
+        <IMAGE_SOURCE>Professional 120 Image</IMAGE_SOURCE>
+    </GENERAL_CREATION_INFO>
+</IMAGE_CREATION>"""
+
+file1_xml_box = """XML Box (xml ) @ (36, 439)
     <IMAGE_CREATION xmlns="http://www.jpeg.org/jpx/1.0/xml" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.jpeg.org/jpx/1.0/xml http://www.jpeg.org/metadata/15444-2.xsd">
-    \t<GENERAL_CREATION_INFO>
-    \t\t<CREATION_TIME>2001-11-01T13:45:00.000-06:00</CREATION_TIME>
-    \t\t<IMAGE_SOURCE>Professional 120 Image</IMAGE_SOURCE>
-    \t</GENERAL_CREATION_INFO>
+        <GENERAL_CREATION_INFO>
+            <CREATION_TIME>2001-11-01T13:45:00.000-06:00</CREATION_TIME>
+            <IMAGE_SOURCE>Professional 120 Image</IMAGE_SOURCE>
+        </GENERAL_CREATION_INFO>
     </IMAGE_CREATION>"""
 
 issue_182_cmap = """Component Mapping Box (cmap) @ (130, 24)
@@ -977,7 +724,7 @@ issue_186_progression_order = """COD marker segment @ (174, 12)
         Number of resolutions:  6
         Code block height, width:  (32 x 32)
         Wavelet transform:  9-7 irreversible
-        Precinct size:  default, 2^15 x 2^15
+        Precinct size:  (32768, 32768)
         Code block context:
             Selective arithmetic coding bypass:  False
             Reset context probabilities on coding pass boundaries:  False
@@ -1038,7 +785,7 @@ goodstuff_codestream_header = r"""Codestream:
             Number of resolutions:  6
             Code block height, width:  (64 x 64)
             Wavelet transform:  5-3 reversible
-            Precinct size:  default, 2^15 x 2^15
+            Precinct size:  (32768, 32768)
             Code block context:
                 Selective arithmetic coding bypass:  False
                 Reset context probabilities on coding pass boundaries:  False
@@ -1073,7 +820,7 @@ goodstuff_with_full_header = r"""Codestream:
             Number of resolutions:  6
             Code block height, width:  (64 x 64)
             Wavelet transform:  5-3 reversible
-            Precinct size:  default, 2^15 x 2^15
+            Precinct size:  (32768, 32768)
             Code block context:
                 Selective arithmetic coding bypass:  False
                 Reset context probabilities on coding pass boundaries:  False
@@ -1096,6 +843,7 @@ goodstuff_with_full_header = r"""Codestream:
             Number of resolutions:  6
             Code block height, width:  (64 x 64)
             Wavelet transform:  5-3 reversible
+            Precinct size:  (32768, 32768)
             Code block context:
                 Selective arithmetic coding bypass:  False
                 Reset context probabilities on coding pass boundaries:  False
@@ -1114,6 +862,7 @@ goodstuff_with_full_header = r"""Codestream:
             Number of resolutions:  6
             Code block height, width:  (64 x 64)
             Wavelet transform:  5-3 reversible
+            Precinct size:  (32768, 32768)
             Code block context:
                 Selective arithmetic coding bypass:  False
                 Reset context probabilities on coding pass boundaries:  False
@@ -1162,3 +911,24 @@ geotiff_uuid = """UUID Box (uuid) @ (149, 523)
 geotiff_uuid_without_gdal = """UUID Box (uuid) @ (149, 523)
     UUID:  b14bf8bd-083d-4b43-a5ae-8cd7d5a6ce03 (GeoTIFF)
     UUID Data:  OrderedDict([('ImageWidth', 1), ('ImageLength', 1), ('BitsPerSample', 8), ('Compression', 1), ('PhotometricInterpretation', 1), ('StripOffsets', 8), ('SamplesPerPixel', 1), ('RowsPerStrip', 1), ('StripByteCounts', 1), ('PlanarConfiguration', 1), ('ModelPixelScale', (0.25, 0.25, 0.0)), ('ModelTiePoint', (0.0, 0.0, 0.0, -2523306.125, -268608.875, 0.0)), ('GeoKeyDirectory', (1, 1, 0, 18, 1024, 0, 1, 1, 1025, 0, 1, 1, 1026, 34737, 21, 0, 2048, 0, 1, 32767, 2049, 34737, 9, 21, 2050, 0, 1, 32767, 2054, 0, 1, 9102, 2056, 0, 1, 32767, 2057, 34736, 1, 4, 2058, 34736, 1, 5, 3072, 0, 1, 32767, 3074, 0, 1, 32767, 3075, 0, 1, 17, 3076, 0, 1, 9001, 3082, 34736, 1, 2, 3083, 34736, 1, 3, 3088, 34736, 1, 1, 3089, 34736, 1, 0)), ('GeoDoubleParams', (0.0, 180.0, 0.0, 0.0, 3396190.0, 3396190.0)), ('GeoAsciiParams', 'Equirectangular MARS|GCS_MARS|')])"""
+
+multiple_precinct_size = """COD marker segment @ (51, 18)
+    Coding style:
+        Entropy coder, with partitions
+        SOP marker segments:  False
+        EPH marker segments:  False
+    Coding style parameters:
+        Progression order:  LRCP
+        Number of layers:  1
+        Multiple component transformation usage:  reversible
+        Number of resolutions:  6
+        Code block height, width:  (64 x 64)
+        Wavelet transform:  5-3 reversible
+        Precinct size:  ((16, 16), (32, 32), (64, 64), (128, 128), (128, 128), (128, 128))
+        Code block context:
+            Selective arithmetic coding bypass:  False
+            Reset context probabilities on coding pass boundaries:  False
+            Termination on each coding pass:  False
+            Vertically stripe causal context:  False
+            Predictable termination:  False
+            Segmentation symbols:  False"""
