@@ -8,6 +8,7 @@ import os
 import struct
 import tempfile
 import unittest
+import warnings
 
 import lxml.etree as ET
 
@@ -17,8 +18,6 @@ from glymur.jp2box import DataEntryURLBox, FileTypeBox, JPEG2000SignatureBox
 from glymur.jp2box import DataReferenceBox, FragmentListBox, FragmentTableBox
 from glymur.jp2box import ColourSpecificationBox
 
-from .fixtures import WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG
-
 
 @unittest.skipIf(os.name == "nt", "Temporary file issue on window.")
 class TestJPXWrap(unittest.TestCase):
@@ -306,14 +305,14 @@ class TestJPXWrap(unittest.TestCase):
             with self.assertRaises(IOError):
                 jp2.wrap(tfile.name, boxes=boxes)
 
-    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_deurl_child_of_dtbl(self):
         """Data reference boxes can only contain data entry url boxes."""
         jp2 = Jp2k(self.jp2file)
         boxes = [jp2.box[idx] for idx in [0, 1, 2, 4]]
 
         ftyp = glymur.jp2box.FileTypeBox()
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
             dref = glymur.jp2box.DataReferenceBox([ftyp])
 
         # Try to get around it by appending the ftyp box after creation.
@@ -432,55 +431,55 @@ class TestJPX(unittest.TestCase):
     def tearDown(self):
         pass
 
-    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_flst_lens_not_the_same(self):
         """A fragment list box items must be the same length."""
         offset = [89]
         length = [1132288]
         reference = [0, 0]
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
             flst = glymur.jp2box.FragmentListBox(offset, length, reference)
-        with self.assertRaises(IOError):
-            with tempfile.TemporaryFile() as tfile:
+        with tempfile.TemporaryFile() as tfile:
+            with self.assertRaises(IOError):
                 flst.write(tfile)
 
-    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_flst_offsets_not_positive(self):
         """A fragment list box offsets must be positive."""
         offset = [0]
         length = [1132288]
         reference = [0]
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
             flst = glymur.jp2box.FragmentListBox(offset, length, reference)
-        with self.assertRaises((IOError, OSError)):
-            with tempfile.TemporaryFile() as tfile:
+        with tempfile.TemporaryFile() as tfile:
+            with self.assertRaises((IOError, OSError)):
                 flst.write(tfile)
 
-    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_flst_lengths_not_positive(self):
         """A fragment list box lengths must be positive."""
         offset = [89]
         length = [0]
         reference = [0]
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
             flst = glymur.jp2box.FragmentListBox(offset, length, reference)
-        with self.assertRaises(IOError):
-            with tempfile.TemporaryFile() as tfile:
+        with tempfile.TemporaryFile() as tfile:
+            with self.assertRaises(IOError):
                 flst.write(tfile)
 
     def test_ftbl_boxes_empty(self):
         """A fragment table box must have at least one child box."""
         ftbl = glymur.jp2box.FragmentTableBox()
-        with self.assertRaises(IOError):
-            with tempfile.TemporaryFile() as tfile:
+        with tempfile.TemporaryFile() as tfile:
+            with self.assertRaises(IOError):
                 ftbl.write(tfile)
 
     def test_ftbl_child_not_flst(self):
         """A fragment table box can only contain a fragment list."""
         free = glymur.jp2box.FreeBox()
         ftbl = glymur.jp2box.FragmentTableBox(box=[free])
-        with self.assertRaises(IOError):
-            with tempfile.TemporaryFile() as tfile:
+        with tempfile.TemporaryFile() as tfile:
+            with self.assertRaises(IOError):
                 ftbl.write(tfile)
 
     def test_data_reference_requires_dtbl(self):
